// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KMAHJONGGLIB_VERSION_H
#define KMAHJONGGLIB_VERSION_H

#define KMAHJONGGLIB_VERSION_STRING "6.0.251203"
#define KMAHJONGGLIB_VERSION_MAJOR 6
#define KMAHJONGGLIB_VERSION_MINOR 0
#define KMAHJONGGLIB_VERSION_PATCH 251203
#define KMAHJONGGLIB_VERSION ((6<<16)|(0<<8)|(251203))

#endif
